==> xulrunner-8.0b1.en-US.win32.zip: jsloader/resource/gre/components/PlacesCategoriesStarter.js <==
  l     1   resource:///components/PlacesCategoriesStarter.js                       L                                 ; 5   Q; 5  Q	: Q; 5  = : Q ; 	Y   ;  = 
: ] ;  Z  >; 5 ^\: ] \6 
Qn Z  >; 	^\o Qn ;  ; : o Q +/`+c3c3/41ccf7 9;?Vcf	XcȰceg6[`0 ff	3           Jb۬ӷe `              F     C c 
   C o m p o n e n t s    c l a s s e s      C i 
   i n t e r f a c e s    M A I N T E N A N C E _ I N T E R V A L _ S E C O N D S    u t i l s      i m p o r t %   r e s o u r c e : / / g r e / m o d u l e s / X P C O M U t i l s . j s m      P l a c e s C a t e g o r i e s S t a r t e r   	   p r o t o t y p e      o b s e r v e      I D $   8 0 3 9 3 8 d 5 - e 2 6 d - 4 4 5 3 - b f 4 6 - a d 4 b 2 6 e 4 1 1 1 4    c l a s s I D   
   X P C O M U t i l s 
   g e n e r a t e Q I    n s I O b s e r v e r      Q u e r y I n t e r f a c e 
   c o m p o n e n t s    N S G e t F a c t o r y    g e n e r a t e N S G e t F a c t o r y           P l a c e s C a t e g o r i e s S t a r t e r                                                            7         Jb۬ӷe `              F  |          P C S _ o b s e r v e   	              a S u b j e c t    a T o p i c    a D a t a                A                           T    G z    	>W  Q;  5  = : W  Q  v     9 ;  :  X: W QV  V ;  ; 5 	 
= : Q;  
:  Q   ; = R p    ̐  ɸD1ccf_ ]{fcg3ccfccM  Ogɰ    ?   
     Jb۬ӷe `              F     S e r v i c e s    p r e f s   
   g e t I n t P r e f    p l a c e s . d a t a b a s e . l a s t M a i n t e n a n c e      p a r s e I n t    D a t e    n o w      M A I N T E N A N C E _ I N T E R V A L _ S E C O N D S 
   C o m p o n e n t s    u t i l s      i m p o r t (   r e s o u r c e : / / g r e / m o d u l e s / P l a c e s D B U t i l s . j s m 
   P l a c e s D B U t i l s      m a i n t e n a n c e O n I d l e      E r r o r   %   T r y i n g   t o   h a n d l e   a n   u n k n o w n   c a t e g o r y .            l a s t M a i n t e n a n c e   
   n o w S e c o n d s             e x             
   i d l e - d a i l y 

==> xulrunner-9.0a1.en-US.win32.zip: jsloader/resource/gre/components/PlacesCategoriesStarter.js <==
  p     1   resource:///components/PlacesCategoriesStarter.js                       L                                    ; 5   Q; 5  Q	: Q; 5  = : Q ; 	Y  ] ;  = 
: ] ;  Z  >; 5 ^\: ] \6 
Qn Z  >; 	^\o Qn ;  ; : o Q +/`+c3c3/41ccf7 9;?Vcf	XcȰceg6[`0 ff	3           Jb۬ӷe `              F      C c 
   C o m p o n e n t s    c l a s s e s      C i 
   i n t e r f a c e s    M A I N T E N A N C E _ I N T E R V A L _ S E C O N D S    u t i l s      i m p o r t %   r e s o u r c e : / / g r e / m o d u l e s / X P C O M U t i l s . j s m      P l a c e s C a t e g o r i e s S t a r t e r   	   p r o t o t y p e      o b s e r v e      I D $   8 0 3 9 3 8 d 5 - e 2 6 d - 4 4 5 3 - b f 4 6 - a d 4 b 2 6 e 4 1 1 1 4    c l a s s I D   
   X P C O M U t i l s 
   g e n e r a t e Q I    n s I O b s e r v e r      Q u e r y I n t e r f a c e 
   c o m p o n e n t s    N S G e t F a c t o r y    g e n e r a t e N S G e t F a c t o r y           P l a c e s C a t e g o r i e s S t a r t e r                                                                 7         Jb۬ӷe `              F            P C S _ o b s e r v e                 a S u b j e c t    a T o p i c    a D a t a                A                              T    G z    	>W  Q;  5  = : W  Q  v     9 ;  :  X: W QV  V ;  ; 5 	 
= : Q;  
:  Q   ; = R p    ̐  ɸD1ccf_ ]{fcg3ccfccM  Ogɰ    ?   
     Jb۬ӷe `              F     S e r v i c e s    p r e f s   
   g e t I n t P r e f    p l a c e s . d a t a b a s e . l a s t M a i n t e n a n c e      p a r s e I n t    D a t e    n o w      M A I N T E N A N C E _ I N T E R V A L _ S E C O N D S 
   C o m p o n e n t s    u t i l s      i m p o r t (   r e s o u r c e : / / g r e / m o d u l e s / P l a c e s D B U t i l s . j s m 
   P l a c e s D B U t i l s      m a i n t e n a n c e O n I d l e      E r r o r   %   T r y i n g   t o   h a n d l e   a n   u n k n o w n   c a t e g o r y .            l a s t M a i n t e n a n c e   
   n o w S e c o n d s             e x             
   i d l e - d a i l y 
